==> jc-1.4.0.tar.gz: javax/security/auth/Policy.h <==
// public abstract class javax.security.auth.Policy

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class 75d342c5cfd2c7ff javax_security_auth_Policy

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_javax_security_auth_Policy_H_
#define _JC_javax_security_auth_Policy_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_security_CodeSource$object;
struct _jc_java_security_PermissionCollection$object;
struct _jc_javax_security_auth_Policy$object;
struct _jc_javax_security_auth_Subject$object;

// Typedefs
typedef struct _jc_javax_security_auth_Policy$sub_refs	_jc_javax_security_auth_Policy$sub_refs;
typedef struct _jc_javax_security_auth_Policy$sub_nonrefs	_jc_javax_security_auth_Policy$sub_nonrefs;
typedef struct _jc_javax_security_auth_Policy$refs	_jc_javax_security_auth_Policy$refs;
typedef struct _jc_javax_security_auth_Policy$nonrefs	_jc_javax_security_auth_Policy$nonrefs;
typedef struct _jc_javax_security_auth_Policy$object	_jc_javax_security_auth_Policy$object;

typedef struct _jc_javax_security_auth_Policy$fields_struct	_jc_javax_security_auth_Policy$fields_struct;
typedef const struct _jc_javax_security_auth_Policy$vmethods	_jc_javax_security_auth_Policy$vmethods;
typedef const struct _jc_javax_security_auth_Policy$vtable	_jc_javax_security_auth_Policy$vtable;
typedef const struct _jc_javax_security_auth_Policy$vtype	_jc_javax_security_auth_Policy$vtype;

// Class fields structure
struct _jc_javax_security_auth_Policy$fields_struct {
	struct _jc_javax_security_auth_Policy$object	*policy;
};
extern _jc_javax_security_auth_Policy$fields_struct _jc_javax_security_auth_Policy$class_fields;

// Constructors
extern void _jc_javax_security_auth_Policy$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_javax_security_auth_Policy$object *);

// Virtual methods
extern struct _jc_java_security_PermissionCollection$object *_jc_javax_security_auth_Policy$method$getPermissions$f899442e41279647(_jc_env *, struct _jc_javax_security_auth_Policy$object *, struct _jc_javax_security_auth_Subject$object *, struct _jc_java_security_CodeSource$object *);
extern void _jc_javax_security_auth_Policy$method$refresh$23f3d9d8f6b36945(_jc_env *, struct _jc_javax_security_auth_Policy$object *);

// Virtual method descriptors
extern _jc_method _jc_javax_security_auth_Policy$method_info$getPermissions$f899442e41279647;
extern _jc_method _jc_javax_security_auth_Policy$method_info$refresh$23f3d9d8f6b36945;

// Static methods
extern struct _jc_javax_security_auth_Policy$object *_jc_javax_security_auth_Policy$method$getPolicy$f3b59869c99a3989(_jc_env *);
extern void _jc_javax_security_auth_Policy$method$setPolicy$c78b4e8a5ef47a71(_jc_env *, struct _jc_javax_security_auth_Policy$object *);

// Virtual methods structure
struct _jc_javax_security_auth_Policy$vmethods {
	struct _jc_java_security_PermissionCollection$object	*(*getPermissions$f899442e41279647)(_jc_env *, struct _jc_javax_security_auth_Policy$object *, struct _jc_javax_security_auth_Subject$object *, struct _jc_java_security_CodeSource$object *);
	void	(*refresh$23f3d9d8f6b36945)(_jc_env *, struct _jc_javax_security_auth_Policy$object *);
};

// Vtable
struct _jc_javax_security_auth_Policy$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_javax_security_auth_Policy$vmethods	javax_security_auth_Policy;
};

// Vtype
struct _jc_javax_security_auth_Policy$vtype {
	_jc_type			type;
	_jc_javax_security_auth_Policy$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_javax_security_auth_Policy$sub_refs {
};

// Reference instance fields (object)
struct _jc_javax_security_auth_Policy$refs {
    _jc_javax_security_auth_Policy$sub_refs	javax_security_auth_Policy;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_javax_security_auth_Policy$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_javax_security_auth_Policy$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_javax_security_auth_Policy$sub_nonrefs	javax_security_auth_Policy;
};

// Object instance structure
struct _jc_javax_security_auth_Policy$object {
	_jc_javax_security_auth_Policy$refs	refs[0];
	_jc_word		lockword;
	_jc_javax_security_auth_Policy$vtype	*vtype;
	_jc_javax_security_auth_Policy$nonrefs	nonrefs;
};

// Type structure
extern _jc_javax_security_auth_Policy$vtype _jc_javax_security_auth_Policy$type;

// Array types class info structures
_JC_DECL_ARRAYS(javax_security_auth_Policy, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_javax_security_auth_Policy$class_object;

#endif	/* _JC_javax_security_auth_Policy_H_ */

==> jc-1.4.6.tar.gz: javax/security/auth/Policy.h <==
// public abstract class javax.security.auth.Policy

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 75d342c5cfd2c7ff javax_security_auth_Policy

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_javax_security_auth_Policy_H_
#define _JC_javax_security_auth_Policy_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_security_CodeSource$object;
struct _jc_java_security_PermissionCollection$object;
struct _jc_javax_security_auth_Policy$object;
struct _jc_javax_security_auth_Subject$object;

// Typedefs
typedef struct _jc_javax_security_auth_Policy$sub_refs	_jc_javax_security_auth_Policy$sub_refs;
typedef struct _jc_javax_security_auth_Policy$sub_nonrefs	_jc_javax_security_auth_Policy$sub_nonrefs;
typedef struct _jc_javax_security_auth_Policy$refs	_jc_javax_security_auth_Policy$refs;
typedef struct _jc_javax_security_auth_Policy$nonrefs	_jc_javax_security_auth_Policy$nonrefs;
typedef struct _jc_javax_security_auth_Policy$object	_jc_javax_security_auth_Policy$object;

typedef struct _jc_javax_security_auth_Policy$fields_struct	_jc_javax_security_auth_Policy$fields_struct;
typedef const struct _jc_javax_security_auth_Policy$vmethods	_jc_javax_security_auth_Policy$vmethods;
typedef const struct _jc_javax_security_auth_Policy$vtable	_jc_javax_security_auth_Policy$vtable;
typedef const struct _jc_javax_security_auth_Policy$vtype	_jc_javax_security_auth_Policy$vtype;

// Class fields structure
struct _jc_javax_security_auth_Policy$fields_struct {
	struct _jc_javax_security_auth_Policy$object	*policy;
};
extern _jc_javax_security_auth_Policy$fields_struct _jc_javax_security_auth_Policy$class_fields;

// Constructors
extern void _jc_javax_security_auth_Policy$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_javax_security_auth_Policy$object *) _JC_JCNI_ATTR;

// Virtual methods
extern struct _jc_java_security_PermissionCollection$object *_jc_javax_security_auth_Policy$method$getPermissions$f899442e41279647(_jc_env *, struct _jc_javax_security_auth_Policy$object *, struct _jc_javax_security_auth_Subject$object *, struct _jc_java_security_CodeSource$object *) _JC_JCNI_ATTR;
extern void _jc_javax_security_auth_Policy$method$refresh$23f3d9d8f6b36945(_jc_env *, struct _jc_javax_security_auth_Policy$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_javax_security_auth_Policy$method_info$getPermissions$f899442e41279647;
extern _jc_method _jc_javax_security_auth_Policy$method_info$refresh$23f3d9d8f6b36945;

// Static methods
extern struct _jc_javax_security_auth_Policy$object *_jc_javax_security_auth_Policy$method$getPolicy$f3b59869c99a3989(_jc_env *) _JC_JCNI_ATTR;
extern void _jc_javax_security_auth_Policy$method$setPolicy$c78b4e8a5ef47a71(_jc_env *, struct _jc_javax_security_auth_Policy$object *) _JC_JCNI_ATTR;

// Virtual methods structure
struct _jc_javax_security_auth_Policy$vmethods {
	struct _jc_java_security_PermissionCollection$object	*(*getPermissions$f899442e41279647)(_jc_env *, struct _jc_javax_security_auth_Policy$object *, struct _jc_javax_security_auth_Subject$object *, struct _jc_java_security_CodeSource$object *) _JC_JCNI_ATTR;
	void	(*refresh$23f3d9d8f6b36945)(_jc_env *, struct _jc_javax_security_auth_Policy$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_javax_security_auth_Policy$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_javax_security_auth_Policy$vmethods	javax_security_auth_Policy;
};

// Vtype
struct _jc_javax_security_auth_Policy$vtype {
	_jc_type			type;
	_jc_javax_security_auth_Policy$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_javax_security_auth_Policy$sub_refs {
};

// Reference instance fields (object)
struct _jc_javax_security_auth_Policy$refs {
    _jc_javax_security_auth_Policy$sub_refs	javax_security_auth_Policy;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_javax_security_auth_Policy$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_javax_security_auth_Policy$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_javax_security_auth_Policy$sub_nonrefs	javax_security_auth_Policy;
};

// Object instance structure
struct _jc_javax_security_auth_Policy$object {
	_jc_javax_security_auth_Policy$refs	refs[0];
	_jc_word		lockword;
	_jc_javax_security_auth_Policy$vtype	*vtype;
	_jc_javax_security_auth_Policy$nonrefs	nonrefs;
};

// Type structure
extern _jc_javax_security_auth_Policy$vtype _jc_javax_security_auth_Policy$type;

// Array types class info structures
_JC_DECL_ARRAYS(javax_security_auth_Policy, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_javax_security_auth_Policy$class_object;

#endif	/* _JC_javax_security_auth_Policy_H_ */
